#
# spec file for package goobox
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           goobox
Version:        3.6.0
Release:        4.6
# FIXME: Enable libcoverart support.
Summary:        CD Player and Ripper for GNOME
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/CD/Grabbers
URL:            https://www.gnome.org
Source0:        https://download.gnome.org/sources/goobox/3.6/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM goobox-Make_pages_pass_yelp_check_validate.patch -- help: Make pages pass yelp-check validate
Patch0:         goobox-Make_pages_pass_yelp_check_validate.patch

BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  meson >= 0.43.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0) >= 2.36
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.0.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10.0
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libbrasero-media3)
#BuildRequires:  pkgconfig(libcoverart) >= 1.0.0
BuildRequires:  pkgconfig(libdiscid)
BuildRequires:  pkgconfig(libmusicbrainz5) >= 5.0.0
BuildRequires:  pkgconfig(libnotify) >= 0.4.3
BuildRequires:  pkgconfig(sm)
%glib2_gsettings_schema_requires

%description
Goobox is a CD player and ripper that always knows just what to do.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file org.gnome.Goobox AudioVideo Player CD
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}

%if 0%{?suse_version} && 0%{?suse_version} < 1330
%post
%glib2_gsettings_schema_post
%desktop_database_post
%icon_theme_cache_post

%postun
%glib2_gsettings_schema_postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%license COPYING
%doc AUTHORS NEWS README
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/goobox
%{_datadir}/applications/org.gnome.Goobox.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Goobox.gschema.xml
%{_datadir}/icons/hicolor/*/apps/goobox.png
%{_datadir}/icons/hicolor/scalable/apps/goobox-symbolic.svg
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.Goobox.appdata.xml

%files lang -f %{name}.lang

%changelog
* Wed Oct 11 2023 Bjørn <bjorn.lie@gmail.com>
- Add goobox-Make_pages_pass_yelp_check_validate.patch: help: Make
  pages pass yelp-check validate.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Apr 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.6.0:
  + Updated translations.
* Mon Feb 18 2019 bjorn.lie@gmail.com
- Update to version 3.5.2:
  + Updated translations.
* Wed Feb  6 2019 bjorn.lie@gmail.com
- Fix translation-update-upstream call, needed after update of
  translation-update-upstream in distro.
* Mon Jan  7 2019 bjorn.lie@gmail.com
- Update to version 3.5.1:
  + New features and user visible changes:
  - Added a volume button.
  - Moved the toolbar on top.
  - Removed application menu.
  - All dialogs use the headerbar.
  - Removed deprecated functions:
    . GTask instead of GSimpleAsyncResult.
    . G_ADD_PRIVATE instead of g_type_class_add_private.
    . GNotification instead of libnotify.
  - Use meson instead of autotools.
  + Bugs fixed:
  - Fixed crash after ejecting a CD.
  - Automatically load rtl icon variants (bgo#768451).
  - Help: change wording in two sentences (bgo#757730).
  - Added -fPIC -DPIC to CFLAGS (bgo#777448).
  + Updated translations.
- Switch to meson buildsystem, add meson BuildRequires and macros.
* Wed Oct  3 2018 bjorn.lie@gmail.com
- Update to version 3.4.3:
  + Help: change wording in two sentences.
  + Added -fPIC -DPIC to CFLAGS.
  + Updated translations.
- Run spec-cleaner, modernize spec.
- Conditionalize post(un) handling of
  glib2_gsettings_schema_post(un), desktop_database_post(un) and
  icon_theme_cache_post(un), no longer needed for modern versions
  of openSUSE.
* Mon Oct 17 2016 zaitor@opensuse.org
- Update to version 3.4.2:
  + Application name not translated in about dialog.
  + Fixed make distcheck.
  + Updated translations.
* Wed Sep 23 2015 zaitor@opensuse.org
- Update to version 3.4.1:
  + Command line arguments not handled correctly.
  + Fix possible crash.
  + Updated translations.
* Wed Apr 15 2015 zaitor@opensuse.org
- Update to version 3.4.0:
  + Correctly update the play button icon after pausing.
  + Added symbolic app icon.
  + Updated translations.
* Fri Feb 27 2015 zaitor@opensuse.org
- Update to version 3.3.3:
  + Allow to start with no drive.
  + Update the window content after changing the drive in the
    preferences.
  + Fixed window auto resize.
  + Updated translations.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.3.2:
  + Updated obsolete info in license text (bgo#721455).
  + Properties: Set button arrow icons according to locale's text
    direction (bgo#722513).
  + notification: Set arrow icons according to locale's text
    direction (bgo#722176).
  + window: Set button arrow icons according to locale's text
    direction (bgo#722174).
  + Require gtk+ 3.10 or higher.
  + Updated translations.
* Wed Jan 15 2014 zaitor@opensuse.org
- Update to version 3.3.1:
  + Added support for writing MP3 files.
  + Preferences: use a single page to show all the preferences.
  + Show a message bar while fetching the disc information.
  + Set button arrow icons according to locale's text direction.
  + Added AppData description.
  + Updated translations.
- Drop goobox-3.8-and_above-compatible.patch, fixed upstream.
* Sun Sep 29 2013 zaitor@opensuse.org
- Add goobox-3.8-and_above-compatible.patch, in order to better fit
  with Gnome 3.8 and newer.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.2.1:
  + Correctly show an error dialog if some gstreamer plugin is
    missing.
  + Faster metadata download using read_sparse (bgo#697966).
  + Use the 'popup' attribute for the GtkMenuButton.
  + Updated translations.
* Thu Mar 28 2013 zaitor@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Wed Mar 20 2013 zaitor@opensuse.org
- Update to version 3.1.2:
  + New features and user visible changes:
  - Use a cover size of 100x100.
  + Bugs fixed:
  - Fixed cover image fetching.
  - Check for ice and sm pkg-config in configure. (bgo#670941).
  + Internal code changes:
  - Ported to libmusicbrainz5.
  - Ported to GStreamer 1.0
  + Updated translations.
- Drop goobox-support-notification-filtering.patch and
  goobox-Port-to-libmusicbrainz5.patch, fixed upstream.
- Drop automake and libtool BuildRequires and stop passing autoconf
  to configure; no longer needed since we do not carry any patches
  anymore.
- Exchange pkgconfig(gstreamer-0.10) for pkgconfig(gstreamer-1.0)
  BuildRequires, following upstream port to gstreamer-1.0.
* Tue Feb 19 2013 zaitor@opensuse.org
- Add goobox-support-notification-filtering.patch, support
  notification filtering.
- Add goobox-Port-to-libmusicbrainz5.patch, port to libmusicbrainz5
- Add automake and libtool BuildRequires and run autoconf since the
  above patch touches the buildsystem.
- Stop passing obsolete --disable-scrollkeeper to configure.
* Tue Dec 18 2012 dimstar@opensuse.org
- Update to version 3.1.1:
  + New features and user visible changes:
  - Implemented a GNOME 3 like interface.
  - Added an application menu.
  - Fixed the window size with big playlists.
  + Bugs fixed:
  - Fixed skipping to a specific position.
  + Internal code changes:
  - Ported to libmusicbrainz 4.
  - Use libcoverart (if available) to get the CD cover.
  - Use GResource to store ui files.
  - Ported to the new documentation infrastructure.
  - Removed markup from translatable messages.
  - Removed use of deprecated functions.
  + Updated translations.
- Add pkgconfig(libcoverart) BuildRequires (currently disabled, as
  we do not yet have a package for it).
- Replace pkgconfig(libmusicbrainz3) BuildRequires with
  pkgconfig(libmusicbrainz4), following upstreams port.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams port to the new documentation infrastructure.
- Drop gconf2 BuildRequires: gconftool-2 is no longer needed.
- Remove conditions for no longer supported openSUSE versions (post
  scripts are now unconditionally configured).
* Sat Oct 13 2012 dimstar@opensuse.org
- Add gconf2 BuildRequires: used to be pulled in implicit by other
  packages. The build system makes use of gconftool-2, and thus
  requires this to be present.
* Fri Mar 30 2012 vuntz@opensuse.org
- Update to version 3.0.1:
  + Fixed compilation linking explicitly to the math library.
  + Updated translations.
* Tue Feb 28 2012 vuntz@opensuse.org
- Add pkgconfig(ice) and pkgconfig(sm) BuildRequires to fix build
  after the relayout of the xorg-x11 packages.
* Tue Oct  4 2011 dimstar@opensuse.org
- Update to version 3.0.0:
  + Removed use of deprecated code.
  + Updated translations.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 2.90.2:
  + Bugs fixed:
  - Fixed loading of the CD when /dev/cdrom doesn't exits.
  - Removed wrong use of the dark theme.
  + Internal code changes:
  - The documentation has been ported to Mallard.
  - Fixed compilation warnings.
  + Updated translations.
* Tue Jun  7 2011 vuntz@opensuse.org
- Update to version 2.90.1:
  + New features and user visible changes:
  - Ported to GTK+ 3.0, GSettings, GDBus, GtkApplication
  - Ported to libmusicbrainz 3
  - Added support for libnotify 0.7
  - Use symbolic icons
  - Preferer the dark theme
  - Added a high definition icon
  - Don't use the status icon with GNOME Shell
  + Bugs fixed:
  - Fixed CD cover search
  + Updated translations.
- Update pkgconfig() BuildRequires for this port to GNOME 3:
  + Drop dbus-glib-1, gconf-2.0, unique-1.0.
  + Change gtk+-2.0, libbrasero-media to gtk+-3.0,
    libbrasero-media3.
- Change libmusicbrainz-devel BuildRequires to
  pkgconfig(libmusibrainz3), and add pkgconfig(libdiscid)
  BuildRequires, for libmusicbrainz3 port.
- Replace GConf2 schemas handling with GSettings schemas handling,
  with %%glib2_gsettings_schema_* macros, and remove gconf-specific
  - -disable-schemas-install configure flag.
* Thu Apr 28 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires:
  + Old ones: brasero-devel, dbus-1-glib-devel, gconf2-devel,
    gstreamer010-devel, libnotify-devel, libunique-devel.
  + New ones: dbus-glib-1, gconf-2.0, glib-2.0, gstreamer-0.10,
    gtk+-2.0, libbrasero-media, libnotify, unique-1.0.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Wed Nov 17 2010 badshah400@gmail.com
- Update to version 2.2.0:
  + Bug fixes:
  - Fixed translation of some strings on the command line help
  - Removed the use of glib/gtk+ deprecated functions
  - Updated the README file
  + Updated translations.
* Wed Aug  4 2010 dimstar@opensuse.org
- Update to version 2.1.2:
  + bgo#624188: Flac quality level 9 does not work
  + bgo#623607: Make sure the cache directory exists before saving
    the file
  + bgo#604437: Save pixbufs.h in the build directory
  + Fixed error when a gstreamer plugin is not available.
  + Updated translations.
* Fri Dec  4 2009 vuntz@opensuse.org
- Update to version 2.1.1:
  + Ported to modern libraries, removed use of deprecated
    functions.
  + Always show the whole track list, without scrollbars.
  + Respect the autoplay setting even at start up time.
  + Added documentation for the preferences dialog.
- Remove gstreamer010-plugins-base-devel, libglade2-devel,
  libgnomeui-devel BuildRequires.
- Add brasero-devel, dbus-1-glib-devel, gconf2-devel,
  gstreamer010-devel, libunique-devel BuildRequires.
- Do not package omf files twice.
* Fri Nov 13 2009 vuntz@opensuse.org
- Update to version 2.0.1:
  + Preferences dialog crash
  + Support transparent tray icon (bgo#554876)
  + Notification action buttons are shown only if notification
    daemon supports actions.
  + Fixed bgo#573162 - Reports "Invalid" device for all my CD
    drives
  + Updated translations.
- Remove unneeded BuildRequires: docbook_4, libidl, libxslt.
- Add libnotify-devel BuildRequires (and remove BuildConflicts).
- Add --disable-scrollkeeper configure option.
- Drop goobox-1.9.2-enable_sk.patch: not needed anymore.
- Drop goobox-1.9.2-ac.patch: not needed anymore.
- Drop goobox-0.9.93-stringcompare.patch: fixed upstream.
- Remove call to autoreconf and intltoolize.
- Remove explicit gconf2 and filesystem PreReq: gconf2 is covered
  by gconf_schemas_prereq.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Sep  3 2008 mboman@novell.com
- Update to version 2.0.0:
  + Fixed bug bgo#478435 – several memory leaks.
  + Open the 'copy cd' dialog on the same screen of the main window.
  + Updated translations
* Tue Apr 15 2008 schwab@suse.de
- Fix configure script.
* Wed Apr  2 2008 maw@suse.de
- Update to version 1.9.2:
  + New features
  + Many, many bugfixes.
- Drop goobox-0.9.2-no_nb.patch
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Sun Jun 17 2007 ro@suse.de
- avoid string compare with char literal
* Mon Mar 26 2007 sbrabec@suse.cz
- Fixed gconf scriptlets.
- Reduced BuildRequires.
* Thu Jan 25 2007 aj@suse.de
- GNOME moves to /usr.
* Fri Oct 13 2006 aj@suse.de
- Add gnome-doc-utils-devel to BuildRequires.
- Cleanup BuildRequires.
- Use RPM_OPT_FLAGS.
* Sun Apr  9 2006 jpr@suse.de
- Port to gstreamer 0.10
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 lmichnovic@suse.cz
- updated to version 0.9.93
- libxslt, gnome-doc-utils added into NFB
- added patch fixing makefile (enable_sk.patch)
- added patch fixing uninitialized variable
* Thu Aug  4 2005 anicka@suse.cz
- update to 0.9.92
- add patch removing no locale
* Thu Feb 10 2005 sbrabec@suse.cz
- Require libsigc++12 in neededforbuild.
* Mon Jan 24 2005 ro@suse.de
- fix lib64 build
* Mon Jan 24 2005 clahey@suse.de
- Initial package.
